==> opentoonz-dmo_1.5.0.orig.tar.xz: opentoonz-1.5.0/toonz/sources/translations/japanese/image.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja_JP" sourcelanguage="en">
<context>
    <name>AviWriterProperties</name>
    <message>
        <location filename="../../image/avi/tiio_avi.cpp" line="1182"/>
        <source>Codec</source>
        <translation>コーデック</translation>
    </message>
    <message>
        <location filename="../../image/avi/tiio_avi.cpp" line="1183"/>
        <source>Uncompressed</source>
        <translation>非圧縮</translation>
    </message>
</context>
<context>
    <name>GifWriterProperties</name>
    <message>
        <location filename="../../image/ffmpeg/tiio_gif.cpp" line="257"/>
        <source>Scale</source>
        <translation>スケール(%)</translation>
    </message>
    <message>
        <location filename="../../image/ffmpeg/tiio_gif.cpp" line="258"/>
        <source>Looping</source>
        <translation>繰り返し再生</translation>
    </message>
    <message>
        <location filename="../../image/ffmpeg/tiio_gif.cpp" line="259"/>
        <source>Generate Palette</source>
        <translation>パレットを生成</translation>
    </message>
</context>
<context>
    <name>Mp4WriterProperties</name>
    <message>
        <location filename="../../image/ffmpeg/tiio_mp4.cpp" line="234"/>
        <source>Quality</source>
        <translation>品質</translation>
    </message>
    <message>
        <location filename="../../image/ffmpeg/tiio_mp4.cpp" line="235"/>
        <source>Scale</source>
        <translation>スケール(%)</translation>
    </message>
</context>
<context>
    <name>PngWriterProperties</name>
    <message>
        <location filename="../../image/png/tiio_png.cpp" line="757"/>
        <source>Alpha Channel</source>
        <translation>アルファチャンネル</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../image/ffmpeg/tiio_ffmpeg.cpp" line="177"/>
        <source>FFmpeg timed out.
Please check the file for errors.
If the file doesn&apos;t play or is incomplete, 
Please try raising the FFmpeg timeout in Preferences.</source>
        <translation>FFmpeg処理がタイムアウトしました。
出力ファイルを確認し、正しく再生しなかったりフレームが足りない場合は
環境設定のFFmpegのタイムアウト時間を増やして再度試してみて下さい。</translation>
    </message>
</context>
<context>
    <name>SgiWriterProperties</name>
    <message>
        <location filename="../../image/sgi/filesgi.cpp" line="1229"/>
        <source>Bits Per Pixel</source>
        <translation>色深度</translation>
    </message>
    <message>
        <location filename="../../image/sgi/filesgi.cpp" line="1230"/>
        <source>24 bits</source>
        <translation>24ビット</translation>
    </message>
    <message>
        <location filename="../../image/sgi/filesgi.cpp" line="1231"/>
        <source>32 bits</source>
        <translation>32ビット</translation>
    </message>
    <message>
        <location filename="../../image/sgi/filesgi.cpp" line="1232"/>
        <source>48 bits</source>
        <translation>48ビット</translation>
    </message>
    <message>
        <location filename="../../image/sgi/filesgi.cpp" line="1233"/>
        <source>64 bits</source>
        <translation>64ビット</translation>
    </message>
    <message>
        <location filename="../../image/sgi/filesgi.cpp" line="1234"/>
        <source>8 bits (Greyscale)</source>
        <translation>8ビット (グレースケール)</translation>
    </message>
    <message>
        <location filename="../../image/sgi/filesgi.cpp" line="1235"/>
        <source>Endianess</source>
        <translation>エンディアン</translation>
    </message>
    <message>
        <location filename="../../image/sgi/filesgi.cpp" line="1236"/>
        <source>Big Endian</source>
        <translation>ビッグエンディアン</translation>
    </message>
    <message>
        <location filename="../../image/sgi/filesgi.cpp" line="1237"/>
        <source>Little Endian</source>
        <translation>リトルエンディアン</translation>
    </message>
    <message>
        <location filename="../../image/sgi/filesgi.cpp" line="1238"/>
        <source>RLE-Compressed</source>
        <translation>RLE圧縮</translation>
    </message>
</context>
<context>
    <name>SpriteWriterProperties</name>
    <message>
        <location filename="../../image/sprite/tiio_sprite.cpp" line="313"/>
        <source>Top Padding</source>
        <translation>上余白</translation>
    </message>
    <message>
        <location filename="../../image/sprite/tiio_sprite.cpp" line="314"/>
        <source>Bottom Padding</source>
        <translation>下余白</translation>
    </message>
    <message>
        <location filename="../../image/sprite/tiio_sprite.cpp" line="315"/>
        <source>Left Padding</source>
        <translation>左余白</translation>
    </message>
    <message>
        <location filename="../../image/sprite/tiio_sprite.cpp" line="316"/>
        <source>Right Padding</source>
        <translation>右余白</translation>
    </message>
    <message>
        <location filename="../../image/sprite/tiio_sprite.cpp" line="317"/>
        <source>Scale</source>
        <translation>スケール(%)</translation>
    </message>
    <message>
        <location filename="../../image/sprite/tiio_sprite.cpp" line="318"/>
        <source>Format</source>
        <translation>画像の並べ方</translation>
    </message>
    <message>
        <location filename="../../image/sprite/tiio_sprite.cpp" line="319"/>
        <source>Grid</source>
        <translation>グリッド</translation>
    </message>
    <message>
        <location filename="../../image/sprite/tiio_sprite.cpp" line="320"/>
        <source>Vertical</source>
        <translation>縦方向</translation>
    </message>
    <message>
        <location filename="../../image/sprite/tiio_sprite.cpp" line="321"/>
        <source>Horizontal</source>
        <translation>横方向</translation>
    </message>
    <message>
        <location filename="../../image/sprite/tiio_sprite.cpp" line="322"/>
        <source>Individual</source>
        <translation>フレーム毎に出力</translation>
    </message>
    <message>
        <location filename="../../image/sprite/tiio_sprite.cpp" line="323"/>
        <source>Trim Empty Space</source>
        <translation>透明部分をトリミングする</translation>
    </message>
</context>
<context>
    <name>SvgWriterProperties</name>
    <message>
        <location filename="../../image/svg/tiio_svg.cpp" line="1969"/>
        <source>Stroke Mode</source>
        <translation>モード</translation>
    </message>
    <message>
        <location filename="../../image/svg/tiio_svg.cpp" line="1970"/>
        <source>Outline Quality</source>
        <translation>アウトラインの品質</translation>
    </message>
    <message>
        <location filename="../../image/svg/tiio_svg.cpp" line="1971"/>
        <source>Centerline</source>
        <translation>中心線</translation>
    </message>
    <message>
        <location filename="../../image/svg/tiio_svg.cpp" line="1972"/>
        <source>Outline</source>
        <translation>アウトライン</translation>
    </message>
    <message>
        <location filename="../../image/svg/tiio_svg.cpp" line="1973"/>
        <source>High</source>
        <translation>高</translation>
    </message>
    <message>
        <location filename="../../image/svg/tiio_svg.cpp" line="1974"/>
        <source>Medium</source>
        <translation>中</translation>
    </message>
    <message>
        <location filename="../../image/svg/tiio_svg.cpp" line="1975"/>
        <source>Low</source>
        <translation>低</translation>
    </message>
</context>
<context>
    <name>TgaWriterProperties</name>
    <message>
        <location filename="../../image/tga/tiio_tga.cpp" line="523"/>
        <source>Bits Per Pixel</source>
        <translation>色深度</translation>
    </message>
    <message>
        <location filename="../../image/tga/tiio_tga.cpp" line="524"/>
        <source>16 bits</source>
        <translation>16ビット</translation>
    </message>
    <message>
        <location filename="../../image/tga/tiio_tga.cpp" line="525"/>
        <source>24 bits</source>
        <translation>24ビット</translation>
    </message>
    <message>
        <location filename="../../image/tga/tiio_tga.cpp" line="526"/>
        <source>32 bits</source>
        <translation>32ビット</translation>
    </message>
    <message>
        <location filename="../../image/tga/tiio_tga.cpp" line="527"/>
        <source>Compression</source>
        <translation>圧縮</translation>
    </message>
</context>
<context>
    <name>TifWriterProperties</name>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="730"/>
        <source>Byte Ordering</source>
        <translation>バイト順序</translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="731"/>
        <source>Compression Type</source>
        <translation>圧縮方式</translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="732"/>
        <source>Bits Per Pixel</source>
        <translation>色深度</translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="733"/>
        <source>24(RGB)</source>
        <translation>24ビット (RGB)</translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="734"/>
        <source>48(RGB)</source>
        <translation>48ビット (RGB)</translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="735"/>
        <source> 1(BW)</source>
        <translation> 1ビット (白黒二値)</translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="736"/>
        <source> 8(GREYTONES)</source>
        <translation> 8ビット (グレースケール)</translation>
    </message>
    <message>
        <source>32(RGBM)</source>
        <translation type="vanished">32ビット (RGBA)</translation>
    </message>
    <message>
        <source>64(RGBM)</source>
        <translation type="vanished">64ビット (RGBA)</translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="737"/>
        <source>32(RGBA)</source>
        <translation>32ビット (RGBA)</translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="738"/>
        <source>64(RGBA)</source>
        <translation>64ビット (RGBA)</translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="739"/>
        <source>Orientation</source>
        <translation>画素の記録方向</translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="740"/>
        <source>Top Left</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="741"/>
        <source>Top Right</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="742"/>
        <source>Bottom Right</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="743"/>
        <source>Bottom Left</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="744"/>
        <source>Left Top</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="745"/>
        <source>Left Bottom</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="746"/>
        <source>Right Top</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="747"/>
        <source>Right Bottom</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>WebmWriterProperties</name>
    <message>
        <location filename="../../image/ffmpeg/tiio_webm.cpp" line="235"/>
        <source>Quality</source>
        <translation>品質</translation>
    </message>
    <message>
        <location filename="../../image/ffmpeg/tiio_webm.cpp" line="236"/>
        <source>Scale</source>
        <translation>スケール(%)</translation>
    </message>
</context>
</TS>

==> opentoonz-dmo_1.6.0.orig.tar.xz: opentoonz-1.6.0/toonz/sources/translations/japanese/image.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja_JP" sourcelanguage="en">
<context>
    <name>AviWriterProperties</name>
    <message>
        <location filename="../../image/avi/tiio_avi.cpp" line="1182"/>
        <source>Codec</source>
        <translation>コーデック</translation>
    </message>
    <message>
        <location filename="../../image/avi/tiio_avi.cpp" line="1183"/>
        <source>Uncompressed</source>
        <translation>非圧縮</translation>
    </message>
</context>
<context>
    <name>ExrWriterProperties</name>
    <message>
        <location filename="../../image/exr/tiio_exr.cpp" line="227"/>
        <source>Bits Per Pixel</source>
        <translation>色深度</translation>
    </message>
    <message>
        <location filename="../../image/exr/tiio_exr.cpp" line="228"/>
        <source>48(RGB Half Float)</source>
        <translation>48ビット (RGB ハーフ浮動小数)</translation>
    </message>
    <message>
        <location filename="../../image/exr/tiio_exr.cpp" line="229"/>
        <source>64(RGBA Half Float)</source>
        <translation>64ビット (RGBA ハーフ浮動小数)</translation>
    </message>
    <message>
        <location filename="../../image/exr/tiio_exr.cpp" line="231"/>
        <source>Compression Type</source>
        <translation>圧縮方式</translation>
    </message>
    <message>
        <location filename="../../image/exr/tiio_exr.cpp" line="233"/>
        <source>No compression</source>
        <translation>圧縮なし</translation>
    </message>
    <message>
        <location filename="../../image/exr/tiio_exr.cpp" line="236"/>
        <source>Run Length Encoding (RLE)</source>
        <translation>Run-Length エンコーディング (RLE)</translation>
    </message>
    <message>
        <location filename="../../image/exr/tiio_exr.cpp" line="239"/>
        <source>ZIP compression per Scanline (ZIPS)</source>
        <translation>Zip圧縮 スキャンライン毎 (ZIPS)</translation>
    </message>
    <message>
        <location filename="../../image/exr/tiio_exr.cpp" line="242"/>
        <source>ZIP compression per scanline band (ZIP)</source>
        <translation>Zip圧縮 スキャンライン バンド毎 (ZIP)</translation>
    </message>
    <message>
        <location filename="../../image/exr/tiio_exr.cpp" line="245"/>
        <source>PIZ-based wavelet compression (PIZ)</source>
        <translation>PIZベース ウェーブレット圧縮 (PIZ)</translation>
    </message>
    <message>
        <location filename="../../image/exr/tiio_exr.cpp" line="247"/>
        <source>Storage Type</source>
        <translation>ストレージ タイプ</translation>
    </message>
    <message>
        <location filename="../../image/exr/tiio_exr.cpp" line="248"/>
        <source>Scan-line based</source>
        <translation>イメージをスキャンラインとして保管</translation>
    </message>
    <message>
        <location filename="../../image/exr/tiio_exr.cpp" line="249"/>
        <source>Tile based</source>
        <translation>イメージをタイルとして保管</translation>
    </message>
</context>
<context>
    <name>GifWriterProperties</name>
    <message>
        <location filename="../../image/ffmpeg/tiio_gif.cpp" line="310"/>
        <source>Global Palette</source>
        <translation>グローバルパレット</translation>
    </message>
    <message>
        <location filename="../../image/ffmpeg/tiio_gif.cpp" line="311"/>
        <source>Global Palette + Sierra Dither</source>
        <translation>グローバルパレット + Sierraディザリング</translation>
    </message>
    <message>
        <location filename="../../image/ffmpeg/tiio_gif.cpp" line="312"/>
        <source>Global Palette + Bayer2 Dither</source>
        <translation>グローバルパレット + Bayerディザリング(スケール2)</translation>
    </message>
    <message>
        <location filename="../../image/ffmpeg/tiio_gif.cpp" line="313"/>
        <source>Global Palette + Bayer1 Dither</source>
        <translation>グローバルパレット + Bayerディザリング(スケール1)</translation>
    </message>
    <message>
        <location filename="../../image/ffmpeg/tiio_gif.cpp" line="314"/>
        <source>Diff Palette</source>
        <translation>フレーム差分から計算</translation>
    </message>
    <message>
        <location filename="../../image/ffmpeg/tiio_gif.cpp" line="315"/>
        <source>Diff Palette + Sierra Dither</source>
        <translation>フレーム差分から計算 + Sierraディザリング</translation>
    </message>
    <message>
        <location filename="../../image/ffmpeg/tiio_gif.cpp" line="316"/>
        <source>Diff Palette + Bayer2 Dither</source>
        <translation>フレーム差分から計算 + Bayerディザリング(スケール2)</translation>
    </message>
    <message>
        <location filename="../../image/ffmpeg/tiio_gif.cpp" line="317"/>
        <source>Diff Palette + Bayer1 Dither</source>
        <translation>フレーム差分から計算 + Bayerディザリング(スケール1)</translation>
    </message>
    <message>
        <location filename="../../image/ffmpeg/tiio_gif.cpp" line="318"/>
        <source>New Pal Per Frame</source>
        <translation>毎フレームパレットを作成</translation>
    </message>
    <message>
        <location filename="../../image/ffmpeg/tiio_gif.cpp" line="319"/>
        <source>New Pal Per Frame + Sierra Dither</source>
        <translation>毎フレーム作成 + Sierraディザリング</translation>
    </message>
    <message>
        <location filename="../../image/ffmpeg/tiio_gif.cpp" line="320"/>
        <source>New Pal Per Frame + Bayer2 Dither</source>
        <translation>毎フレーム作成 + Bayerディザリング(スケール2)</translation>
    </message>
    <message>
        <location filename="../../image/ffmpeg/tiio_gif.cpp" line="321"/>
        <source>New Pal Per Frame + Bayer1 Dither</source>
        <translation>毎フレーム作成 + Bayerディザリング(スケール1)</translation>
    </message>
    <message>
        <location filename="../../image/ffmpeg/tiio_gif.cpp" line="322"/>
        <source>Opaque, Dither, 256 Colors Only</source>
        <translation>パレット最適化なし</translation>
    </message>
    <message>
        <location filename="../../image/ffmpeg/tiio_gif.cpp" line="335"/>
        <source>Scale</source>
        <translation>スケール(%)</translation>
    </message>
    <message>
        <location filename="../../image/ffmpeg/tiio_gif.cpp" line="336"/>
        <source>Looping</source>
        <translation>繰り返し再生</translation>
    </message>
    <message>
        <location filename="../../image/ffmpeg/tiio_gif.cpp" line="337"/>
        <source>Mode</source>
        <translation>パレット最適化</translation>
    </message>
    <message>
        <location filename="../../image/ffmpeg/tiio_gif.cpp" line="338"/>
        <source>Max Colors</source>
        <translation>最大色数</translation>
    </message>
    <message>
        <source>Generate Palette</source>
        <translation type="vanished">パレットを生成</translation>
    </message>
</context>
<context>
    <name>Mp4WriterProperties</name>
    <message>
        <location filename="../../image/ffmpeg/tiio_mp4.cpp" line="234"/>
        <source>Quality</source>
        <translation>品質</translation>
    </message>
    <message>
        <location filename="../../image/ffmpeg/tiio_mp4.cpp" line="235"/>
        <source>Scale</source>
        <translation>スケール(%)</translation>
    </message>
</context>
<context>
    <name>PngWriterProperties</name>
    <message>
        <location filename="../../image/png/tiio_png.cpp" line="757"/>
        <source>Alpha Channel</source>
        <translation>アルファチャンネル</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../image/ffmpeg/tiio_ffmpeg.cpp" line="213"/>
        <source>FFmpeg returned error-code: %1</source>
        <translation>FFmpeg処理はエラーコード %1 で終了しました</translation>
    </message>
    <message>
        <location filename="../../image/ffmpeg/tiio_ffmpeg.cpp" line="217"/>
        <source>FFmpeg timed out.
Please check the file for errors.
If the file doesn&apos;t play or is incomplete, 
Please try raising the FFmpeg timeout in Preferences.</source>
        <translation>FFmpeg処理がタイムアウトしました。
出力ファイルを確認し、正しく再生しなかったりフレームが足りない場合は
環境設定のFFmpegのタイムアウト時間を増やして再度試してみて下さい。</translation>
    </message>
</context>
<context>
    <name>SgiWriterProperties</name>
    <message>
        <location filename="../../image/sgi/filesgi.cpp" line="1229"/>
        <source>Bits Per Pixel</source>
        <translation>色深度</translation>
    </message>
    <message>
        <location filename="../../image/sgi/filesgi.cpp" line="1230"/>
        <source>24 bits</source>
        <translation>24ビット</translation>
    </message>
    <message>
        <location filename="../../image/sgi/filesgi.cpp" line="1231"/>
        <source>32 bits</source>
        <translation>32ビット</translation>
    </message>
    <message>
        <location filename="../../image/sgi/filesgi.cpp" line="1232"/>
        <source>48 bits</source>
        <translation>48ビット</translation>
    </message>
    <message>
        <location filename="../../image/sgi/filesgi.cpp" line="1233"/>
        <source>64 bits</source>
        <translation>64ビット</translation>
    </message>
    <message>
        <location filename="../../image/sgi/filesgi.cpp" line="1234"/>
        <source>8 bits (Greyscale)</source>
        <translation>8ビット (グレースケール)</translation>
    </message>
    <message>
        <location filename="../../image/sgi/filesgi.cpp" line="1235"/>
        <source>Endianess</source>
        <translation>エンディアン</translation>
    </message>
    <message>
        <location filename="../../image/sgi/filesgi.cpp" line="1236"/>
        <source>Big Endian</source>
        <translation>ビッグエンディアン</translation>
    </message>
    <message>
        <location filename="../../image/sgi/filesgi.cpp" line="1237"/>
        <source>Little Endian</source>
        <translation>リトルエンディアン</translation>
    </message>
    <message>
        <location filename="../../image/sgi/filesgi.cpp" line="1238"/>
        <source>RLE-Compressed</source>
        <translation>RLE圧縮</translation>
    </message>
</context>
<context>
    <name>SpriteWriterProperties</name>
    <message>
        <location filename="../../image/sprite/tiio_sprite.cpp" line="313"/>
        <source>Top Padding</source>
        <translation>上余白</translation>
    </message>
    <message>
        <location filename="../../image/sprite/tiio_sprite.cpp" line="314"/>
        <source>Bottom Padding</source>
        <translation>下余白</translation>
    </message>
    <message>
        <location filename="../../image/sprite/tiio_sprite.cpp" line="315"/>
        <source>Left Padding</source>
        <translation>左余白</translation>
    </message>
    <message>
        <location filename="../../image/sprite/tiio_sprite.cpp" line="316"/>
        <source>Right Padding</source>
        <translation>右余白</translation>
    </message>
    <message>
        <location filename="../../image/sprite/tiio_sprite.cpp" line="317"/>
        <source>Scale</source>
        <translation>スケール(%)</translation>
    </message>
    <message>
        <location filename="../../image/sprite/tiio_sprite.cpp" line="318"/>
        <source>Format</source>
        <translation>画像の並べ方</translation>
    </message>
    <message>
        <location filename="../../image/sprite/tiio_sprite.cpp" line="319"/>
        <source>Grid</source>
        <translation>グリッド</translation>
    </message>
    <message>
        <location filename="../../image/sprite/tiio_sprite.cpp" line="320"/>
        <source>Vertical</source>
        <translation>縦方向</translation>
    </message>
    <message>
        <location filename="../../image/sprite/tiio_sprite.cpp" line="321"/>
        <source>Horizontal</source>
        <translation>横方向</translation>
    </message>
    <message>
        <location filename="../../image/sprite/tiio_sprite.cpp" line="322"/>
        <source>Individual</source>
        <translation>フレーム毎に出力</translation>
    </message>
    <message>
        <location filename="../../image/sprite/tiio_sprite.cpp" line="323"/>
        <source>Trim Empty Space</source>
        <translation>透明部分をトリミングする</translation>
    </message>
</context>
<context>
    <name>SvgWriterProperties</name>
    <message>
        <location filename="../../image/svg/tiio_svg.cpp" line="1969"/>
        <source>Stroke Mode</source>
        <translation>モード</translation>
    </message>
    <message>
        <location filename="../../image/svg/tiio_svg.cpp" line="1970"/>
        <source>Outline Quality</source>
        <translation>アウトラインの品質</translation>
    </message>
    <message>
        <location filename="../../image/svg/tiio_svg.cpp" line="1971"/>
        <source>Centerline</source>
        <translation>中心線</translation>
    </message>
    <message>
        <location filename="../../image/svg/tiio_svg.cpp" line="1972"/>
        <source>Outline</source>
        <translation>アウトライン</translation>
    </message>
    <message>
        <location filename="../../image/svg/tiio_svg.cpp" line="1973"/>
        <source>High</source>
        <translation>高</translation>
    </message>
    <message>
        <location filename="../../image/svg/tiio_svg.cpp" line="1974"/>
        <source>Medium</source>
        <translation>中</translation>
    </message>
    <message>
        <location filename="../../image/svg/tiio_svg.cpp" line="1975"/>
        <source>Low</source>
        <translation>低</translation>
    </message>
</context>
<context>
    <name>TgaWriterProperties</name>
    <message>
        <location filename="../../image/tga/tiio_tga.cpp" line="523"/>
        <source>Bits Per Pixel</source>
        <translation>色深度</translation>
    </message>
    <message>
        <location filename="../../image/tga/tiio_tga.cpp" line="524"/>
        <source>16 bits</source>
        <translation>16ビット</translation>
    </message>
    <message>
        <location filename="../../image/tga/tiio_tga.cpp" line="525"/>
        <source>24 bits</source>
        <translation>24ビット</translation>
    </message>
    <message>
        <location filename="../../image/tga/tiio_tga.cpp" line="526"/>
        <source>32 bits</source>
        <translation>32ビット</translation>
    </message>
    <message>
        <location filename="../../image/tga/tiio_tga.cpp" line="527"/>
        <source>Compression</source>
        <translation>圧縮</translation>
    </message>
</context>
<context>
    <name>TifWriterProperties</name>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="730"/>
        <source>Byte Ordering</source>
        <translation>バイト順序</translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="731"/>
        <source>Compression Type</source>
        <translation>圧縮方式</translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="732"/>
        <source>Bits Per Pixel</source>
        <translation>色深度</translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="733"/>
        <source>24(RGB)</source>
        <translation>24ビット (RGB)</translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="734"/>
        <source>48(RGB)</source>
        <translation>48ビット (RGB)</translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="735"/>
        <source> 1(BW)</source>
        <translation> 1ビット (白黒二値)</translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="736"/>
        <source> 8(GREYTONES)</source>
        <translation> 8ビット (グレースケール)</translation>
    </message>
    <message>
        <source>32(RGBM)</source>
        <translation type="vanished">32ビット (RGBA)</translation>
    </message>
    <message>
        <source>64(RGBM)</source>
        <translation type="vanished">64ビット (RGBA)</translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="737"/>
        <source>32(RGBA)</source>
        <translation>32ビット (RGBA)</translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="738"/>
        <source>64(RGBA)</source>
        <translation>64ビット (RGBA)</translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="739"/>
        <source>Orientation</source>
        <translation>画素の記録方向</translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="740"/>
        <source>Top Left</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="741"/>
        <source>Top Right</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="742"/>
        <source>Bottom Right</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="743"/>
        <source>Bottom Left</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="744"/>
        <source>Left Top</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="745"/>
        <source>Left Bottom</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="746"/>
        <source>Right Top</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../image/tif/tiio_tif.cpp" line="747"/>
        <source>Right Bottom</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>WebmWriterProperties</name>
    <message>
        <location filename="../../image/ffmpeg/tiio_webm.cpp" line="235"/>
        <source>Quality</source>
        <translation>品質</translation>
    </message>
    <message>
        <location filename="../../image/ffmpeg/tiio_webm.cpp" line="236"/>
        <source>Scale</source>
        <translation>スケール(%)</translation>
    </message>
</context>
</TS>
